@@ -210,9 +210,6 @@ class GuiAppContent(Gui, ScreenShooter):
         '''
         return self._automator.dom_root(self)
 
-    def _frame(self, *str_or_with_locators):
-        return self._automator.frame(self, self.convert_to_with_wmd(*str_or_with_locators))
-
     @property
     def _alert(self):
         return self._automator.alert
@@ -331,4 +328,17 @@ class GuiAppContent(Gui, ScreenShooter):
         '''
         return self._finder.radio_group(fargs=fargs, **kwargs)
 
+    def frame(self, fargs=None, **kwargs):
+        '''
+            Locate a `GuiFrame`
+
+            Keyword Arguments:
+                fargs: A dictionary of key-value pairs for formatting the `GuiWidgetDefinition`. Use **.format(kwargs).wait_until_absent** for more Pythonic code when formatting.
+                **kwargs: Arbitrary key-value pairs used to construct a `GuiWidgetDefinition`
+
+            Returns:
+                `GuiFrame` object
+        '''
+        return self._finder.frame(fargs=fargs, **kwargs)
+
 
